@@ -4,17 +4,18 @@ module Statistics  ! ײϴطΥ롼
 
 contains
 
-subroutine Mean_1d( nx, x, ave, error )  ! 1 ʿͷ׻롼
+subroutine Mean_1d( x, ave, error )  ! 1 ʿͷ׻롼
   implicit none
-  integer, intent(in) :: nx  ! ǡǿ
-  real, intent(in) :: x(nx)  ! ǡ
+  real, intent(in) :: x(:)  ! ǡ
   real, intent(inout) :: ave  ! ׻ʿ
   real, intent(in), optional :: error  ! »ͤ¸ߤǡåȤξη»
   integer :: i, nt
+  integer :: nx  ! ǡǿ
   real :: summ
 
   summ=0.0
   nt=0
+  nx=size(x)
 
   if(present(error))then
      do i=1,nx
@@ -43,18 +44,20 @@ subroutine Mean_1d( nx, x, ave, error )  ! 1 ʿͷ׻롼
 end subroutine Mean_1d
 
 
-subroutine Mean_2d( nx, ny, x, ave, error )  ! 2 ʿͷ׻롼
+subroutine Mean_2d( x, ave, error )  ! 2 ʿͷ׻롼
   implicit none
-  integer, intent(in) :: nx  ! ǡǿ 1
-  integer, intent(in) :: ny  ! ǡǿ 2
-  real, intent(in) :: x(nx,ny)  ! ǡ
+  real, intent(in) :: x(:,:)  ! ǡ
   real, intent(inout) :: ave  ! ׻ʿ
   real, intent(in), optional :: error  ! »ͤ¸ߤǡåȤξη»
   integer :: i, j, nt
+  integer :: nx  ! ǡǿ 1
+  integer :: ny  ! ǡǿ 2
   real :: summ, tmp
 
   summ=0.0
   nt=0
+  nx=size(x,1)
+  ny=size(x,2)
 
   if(present(error))then
      do j=1,ny
@@ -87,19 +90,22 @@ subroutine Mean_2d( nx, ny, x, ave, error )  ! 2 ʿͷ׻롼
 end subroutine Mean_2d
 
 
-subroutine Mean_3d( nx, ny, nz, x, ave, error )  ! 3 ʿͷ׻롼
+subroutine Mean_3d( x, ave, error )  ! 3 ʿͷ׻롼
   implicit none
-  integer, intent(in) :: nx  ! ǡǿ 1
-  integer, intent(in) :: ny  ! ǡǿ 2
-  integer, intent(in) :: nz  ! ǡǿ 2
-  real, intent(in) :: x(nx,ny,nz)  ! ǡ
+  real, intent(in) :: x(:,:,:)  ! ǡ
   real, intent(inout) :: ave  ! ׻ʿ
   real, intent(in), optional :: error  ! »ͤ¸ߤǡåȤξη»
   integer :: i, j, k, nt
+  integer :: nx  ! ǡǿ 1
+  integer :: ny  ! ǡǿ 2
+  integer :: nz  ! ǡǿ 2
   real :: summ, tmp
 
   summ=0.0
   nt=0
+  nx=size(x,1)
+  ny=size(x,2)
+  nz=size(x,3)
 
   if(present(error))then
      do k=1,nz
@@ -136,17 +142,17 @@ subroutine Mean_3d( nx, ny, nz, x, ave, error )  ! 3 ʿͷ׻롼
 end subroutine Mean_3d
 
 
-subroutine Anomaly_1d( nx, x, anor, error )  ! 1 ǡк֤
+subroutine Anomaly_1d( x, anor, error )  ! 1 ǡк֤
   implicit none
-  integer, intent(in) :: nx  ! ǡǿ
-  real, intent(in) :: x(nx)  ! ǡ
-  real, intent(inout) :: anor(nx)  !  x(i) бк anor(i)
+  real, intent(in) :: x(:)  ! ǡ
+  real, intent(inout) :: anor(size(x))  !  x(i) бк anor(i)
   real, intent(in), optional :: error  ! »ͤ¸ߤǡåȤξη»
   integer :: i
+  integer :: nx  ! ǡǿ
   real :: ave
 
   if(present(error))then
-     call Mean_1d( nx, x, ave, error )
+     call Mean_1d( x, ave, error )
      do i=1,nx
         if(x(i)==error)then
            anor(i)=error
@@ -155,7 +161,7 @@ subroutine Anomaly_1d( nx, x, anor, error )  ! 1 ǡк֤
         end if
      end do
   else
-     call Mean_1d( nx, x, ave )
+     call Mean_1d( x, ave )
      do i=1,nx
         anor(i)=x(i)-ave
      end do
@@ -164,18 +170,21 @@ subroutine Anomaly_1d( nx, x, anor, error )  ! 1 ǡк֤
 end subroutine Anomaly_1d
 
 
-subroutine Anomaly_2d( nx, ny, x, anor, error )  ! 2 ǡк֤
+subroutine Anomaly_2d( x, anor, error )  ! 2 ǡк֤
   implicit none
-  integer, intent(in) :: nx  ! ǡǿ 1
-  integer, intent(in) :: ny  ! ǡǿ 2
-  real, intent(in) :: x(nx,ny)  ! ǡ
-  real, intent(inout) :: anor(nx,ny)  !  x(i,j) бк anor(i,j)
+  real, intent(in) :: x(:,:)  ! ǡ
+  real, intent(inout) :: anor(size(x,1),size(x,2))  !  x(i,j) бк anor(i,j)
   real, intent(in), optional :: error  ! »ͤ¸ߤǡåȤξη»
   integer :: i, j
+  integer :: nx  ! ǡǿ 1
+  integer :: ny  ! ǡǿ 2
   real :: ave
 
+  nx=size(x,1)
+  ny=size(x,2)
+
   if(present(error))then
-     call Mean_2d( nx, ny, x, ave, error )
+     call Mean_2d( x, ave, error )
      do j=1,ny
         do i=1,nx
            if(x(i,j)==error)then
@@ -186,7 +195,7 @@ subroutine Anomaly_2d( nx, ny, x, anor, error )  ! 2 ǡк֤
         end do
      end do
   else
-     call Mean_2d( nx, ny, x, ave, error )
+     call Mean_2d( x, ave, error )
      do j=1,ny
         do i=1,nx
            anor(i,j)=x(i,j)-ave
@@ -197,19 +206,23 @@ subroutine Anomaly_2d( nx, ny, x, anor, error )  ! 2 ǡк֤
 end subroutine Anomaly_2d
 
 
-subroutine Anomaly_3d( nx, ny, nz, x, anor, error )  ! 3 ǡк֤
+subroutine Anomaly_3d( x, anor, error )  ! 3 ǡк֤
   implicit none
-  integer, intent(in) :: nx  ! ǡǿ 1
-  integer, intent(in) :: ny  ! ǡǿ 2
-  integer, intent(in) :: nz  ! ǡǿ 3
-  real, intent(in) :: x(nx,ny,nz)  ! ǡ
-  real, intent(inout) :: anor(nx,ny,nz)  !  x(i,j,k) бк anor(i,j,k)
+  real, intent(in) :: x(:,:,:)  ! ǡ
+  real, intent(inout) :: anor(size(x,1),size(x,2),size(x,3))  !  x(i,j,k) бк anor(i,j,k)
   real, intent(in), optional :: error  ! »ͤ¸ߤǡåȤξη»
   integer :: i, j, k
+  integer :: nx  ! ǡǿ 1
+  integer :: ny  ! ǡǿ 2
+  integer :: nz  ! ǡǿ 3
   real :: ave
 
+  nx=size(x,1)
+  ny=size(x,2)
+  nz=size(x,3)
+
   if(present(error))then
-     call Mean_3d( nx, ny, nz, x, ave, error )
+     call Mean_3d( x, ave, error )
      do k=1,nz
         do j=1,ny
            do i=1,nx
@@ -222,7 +235,7 @@ subroutine Anomaly_3d( nx, ny, nz, x, anor, error )  ! 3 ǡк֤
         end do
      end do
   else
-     call Mean_3d( nx, ny, nz, x, ave, error )
+     call Mean_3d( x, ave, error )
      do k=1,nz
         do j=1,ny
            do i=1,nx
@@ -235,29 +248,30 @@ subroutine Anomaly_3d( nx, ny, nz, x, anor, error )  ! 3 ǡк֤
 end subroutine Anomaly_3d
 
 
-subroutine stand_vari( nx, x, anor, error )  ! 1 ǡɸк׻
+subroutine stand_vari( x, anor, error )  ! 1 ǡɸк׻
   ! ɸк$\sigma $,
   ! $$\sigma =\sum^{nx}_{i=1}{epsilon ^2} $$
   ! , $\epsilon $ʿͤΤ$x-\bar{x}$Ǥ.
   implicit none
-  integer, intent(in) :: nx  ! ǡ
-  real, intent(in) :: x(nx)  ! ǡ
+  real, intent(in) :: x(:)  ! ǡ
   real, intent(inout) :: anor  ! ɸк
   real, intent(in), optional :: error  ! »
   integer :: i
-  real :: an(nx)
+  integer :: nx  ! ǡ
+  real :: an(size(x))
 
+  nx=size(x)
   anor=0.0
 
   if(present(error))then
-     call Anomaly_1d( nx, x, an, error )
+     call Anomaly_1d( x, an, error )
      do i=1,nx
         if(x(i)/=error)then
            anor=anor+an(i)**2
         end if
      end do
   else
-     call Anomaly_1d( nx, x, an )
+     call Anomaly_1d( x, an )
      do i=1,nx
         anor=anor+an(i)**2
      end do
@@ -265,31 +279,32 @@ subroutine stand_vari( nx, x, anor, error )  ! 1 ǡɸк׻
 
 end subroutine stand_vari
 
-subroutine covariance( nx, x, y, cov, error )  ! 2 Ĥ 1 ǡζʬ׻
+subroutine covariance( x, y, cov, error )  ! 2 Ĥ 1 ǡζʬ׻
   ! ʬ$\sigma $,
   ! $$\sigma =\sum^{nx}_{i=1}{(x-\bar{x})(y-\bar{y})} $$
   implicit none
-  integer, intent(in) :: nx  ! ǡ
-  real, intent(in) :: x(nx)  ! ǡ 1
-  real, intent(in) :: y(nx)  ! ǡ 2
+  real, intent(in) :: x(:)  ! ǡ 1
+  real, intent(in) :: y(size(x))  ! ǡ 2
   real, intent(inout) :: cov  ! ɸк
   real, intent(in), optional :: error  ! »
   integer :: i
-  real :: an1(nx), an2(nx)
+  integer :: nx  ! ǡ
+  real :: an1(size(x)), an2(size(x))
 
+  nx=size(x)
   cov=0.0
 
   if(present(error))then
-     call Anomaly_1d( nx, x, an1, error )
-     call Anomaly_1d( nx, y, an2, error )
+     call Anomaly_1d( x, an1, error )
+     call Anomaly_1d( y, an2, error )
      do i=1,nx
         if(x(i)/=error)then
            cov=cov+an1(i)*an2(i)
         end if
      end do
   else
-     call Anomaly_1d( nx, x, an1 )
-     call Anomaly_1d( nx, y, an2 )
+     call Anomaly_1d( x, an1 )
+     call Anomaly_1d( y, an2 )
      do i=1,nx
         cov=cov+an1(i)*an2(i)
      end do
@@ -569,18 +584,19 @@ end subroutine interpolation_3d
 
 
 
-subroutine LSM( nx, x, y, slope, intercept, undef )  ! Ǿˡˤ뷹ҷ׻
+subroutine LSM( x, y, slope, intercept, undef )  ! Ǿˡˤ뷹ҷ׻
   implicit none
-  integer, intent(in) :: nx  ! ǡ
-  real, intent(in) :: x(nx)  ! ǡ 1
-  real, intent(in) :: y(nx)  ! ǡ 2
+  real, intent(in) :: x(:)  ! ǡ 1
+  real, intent(in) :: y(size(x))  ! ǡ 2
   real, intent(inout) :: slope  ! Ŭʷ
   real, intent(inout) :: intercept  ! Ŭ
   real, intent(in), optional :: undef ! undef 
-  real :: u(nx), v(nx)
+  real :: u(size(x)), v(size(x))
   integer :: i, j, k
+  integer :: nx  ! ǡ
   real :: a, b, c, d
 
+  nx=size(x)
   a=0.0
   b=0.0
   c=0.0
@@ -593,10 +609,10 @@ subroutine LSM( nx, x, y, slope, intercept, undef )  ! Ǿˡˤ뷹ҷ׻
   end do
 !$omp end parallel do
 
-  call summ(nx,v,a,undef)
-  call summ(nx,x,b,undef)
-  call summ(nx,y,c,undef)
-  call summ(nx,u,d,undef)
+  call summ(v,a,undef)
+  call summ(x,b,undef)
+  call summ(y,c,undef)
+  call summ(u,d,undef)
 
   slope=(nx*a-b*c)/(nx*d-b**2)
   intercept=(c*d-a*b)/(nx*d-b**2)
@@ -605,7 +621,7 @@ end subroutine LSM
 
 !------------------------------------
 
-subroutine LSM_poly( poly_n, nx, x, y, a, intercept, undef )
+subroutine LSM_poly( x, y, a, intercept, undef )
 ! LSM ¿༰С.
 ! LSM Ǥ, F(x)=a_0+a_1x ľԤäƤ,
 ! LSM_poly Ǥ, F(x)=\sum^{N}_{n=0}{a_nx^n}
@@ -613,22 +629,24 @@ subroutine LSM_poly( poly_n, nx, x, y, a, intercept, undef )
 ! 르ꥺϺǾˡѤƤ, ΥФˤ gausss 롼.
   use Algebra
   implicit none
-  integer, intent(in) :: poly_n  ! κǹ⼡. 1 ʤ, LSM Ʊ.
-  integer, intent(in) :: nx  ! ǡθĿ
-  real, intent(in) :: x(nx)  ! ǡ 1
-  real, intent(in) :: y(nx)  ! ǡ 2
-  real, intent(inout) :: a(poly_n)  ! ¿༰η
+  real, intent(in) :: x(:)  ! ǡ 1
+  real, intent(in) :: y(size(x))  ! ǡ 2
+  real, intent(inout) :: a(:)  ! ¿༰η
   real, intent(inout) :: intercept  ! y . 
                          ! a Ȥ߹ȰϤȤ, poly_n+1 Ϥɬפ
                          ! , ʶ路ȽǤ, a_0 Ǥ y Ҥ
                          ! ΩǰȤϤȤˤ.
   real, intent(in), optional :: undef  ! ̤.
   integer :: i, j, k, l, m, n
-  real :: coe(0:poly_n), tmpa_coe(0:poly_n,0:poly_n), tmpb_coe(0:poly_n)
+  integer :: nx  ! ǡθĿ
+  integer :: poly_n  ! κǹ⼡. 1 ʤ, LSM Ʊ.
+  real :: coe(0:size(a)), tmpa_coe(0:size(a),0:size(a)), tmpb_coe(0:size(a))
           ! coe  a_n . tmp_coe ϥǡ¤.
           ! [] : Ǥ. Ǥ.
-  real :: tmp(nx)  ! ٤׻ΰ
+  real :: tmp(size(x))  ! ٤׻ΰ
 
+  nx=size(x)
+  poly_n=size(a)
 
 !-- gausss Ϥ䤹褦, Ѱդ˰.
   if(present(undef))then
@@ -643,7 +661,7 @@ subroutine LSM_poly( poly_n, nx, x, y, a, intercept, undef )
                     tmp(i)=undef
                  end if
               end do
-              call summ( nx, tmp, tmpa_coe(j,k), undef )
+              call summ( tmp, tmpa_coe(j,k), undef )
            else  ! ʬ(j)ʬ(k)ǿ礭, 򤯷
                  ! оιǤ뤳Ȥ, ͤλΤ߹Ԥ.
               tmpa_coe(j,k)=tmpa_coe(k,j)  ! оʬʤǤ˷׻Ѥߡ
@@ -658,7 +676,7 @@ subroutine LSM_poly( poly_n, nx, x, y, a, intercept, undef )
               tmp(i)=undef
            end if
         end do
-        call summ( nx, tmp, tmpb_coe(j), undef )
+        call summ( tmp, tmpb_coe(j), undef )
      end do
   else  ! undef ʤȤ.
      do k=0,poly_n  ! ʬη׻
@@ -668,7 +686,7 @@ subroutine LSM_poly( poly_n, nx, x, y, a, intercept, undef )
               do i=1,nx
                  tmp(i)=x(i)**(j+k)
               end do
-              call summ( nx, tmp, tmpa_coe(j,k), undef )
+              call summ( tmp, tmpa_coe(j,k), undef )
            else  ! ʬ(j)ʬ(k)ǿ礭, 򤯷
                  ! оιǤ뤳Ȥ, ͤλΤ߹Ԥ.
               tmpa_coe(j,k)=tmpa_coe(k,j)  ! оʬʤǤ˷׻Ѥߡ
@@ -679,7 +697,7 @@ subroutine LSM_poly( poly_n, nx, x, y, a, intercept, undef )
         do i=1,nx
            tmp(i)=y(i)*(x(i)**j)
         end do
-        call summ( nx, tmp, tmpb_coe(j), undef )
+        call summ( tmp, tmpb_coe(j), undef )
      end do
   end if
 
@@ -697,40 +715,44 @@ end subroutine
 
 !------------------------------------
 
-subroutine Reg_Line( nx, x, y, slope, intercept )
+subroutine Reg_Line( x, y, slope, intercept )
   ! LSM ѤƲľη slope  intercept ׻롼
   implicit none
-  integer, intent(in) :: nx  ! ǡ
-  real, intent(in) :: x(nx)  ! ǡ 1
-  real, intent(in) :: y(nx)  ! ǡ 2
+  real, intent(in) :: x(:)  ! ǡ 1
+  real, intent(in) :: y(size(x))  ! ǡ 2
   real, intent(inout) :: slope  ! Ŭʷ
   real, intent(inout) :: intercept  ! Ŭ
-  real :: u(nx), v(nx)
+  real :: u(size(x)), v(size(x))
+  integer :: nx  ! ǡ
 
-  call Anomaly_1d( nx, x, u )
-  call Anomaly_1d( nx, y, v )
-  call LSM( nx, u, v, slope, intercept )
+  nx=size(x)
+
+  call Anomaly_1d( x, u )
+  call Anomaly_1d( y, v )
+  call LSM( u, v, slope, intercept )
 
 end subroutine
 
-subroutine Cor_Coe( nx, x, y ,cc, error )  ! 2 ǡط׻롼
+subroutine Cor_Coe( x, y ,cc, error )  ! 2 ǡط׻롼
   implicit none
-  integer, intent(in) :: nx  ! ǡĿ
-  real, intent(in) :: x(nx)  ! ǡ 1
-  real, intent(in) :: y(nx)  ! ǡ 2
+  real, intent(in) :: x(:)  ! ǡ 1
+  real, intent(in) :: y(size(x))  ! ǡ 2
   real, intent(inout) :: cc  ! ط
   real, intent(in), optional :: error  ! »
   integer :: i
+  integer :: nx  ! ǡĿ
   real :: cov, anor1, anor2
 
+  nx=size(x)
+
   if(present(error))then
-     call covariance( nx, x, y, cov, error )
-     call stand_vari( nx, x, anor1, error )
-     call stand_vari( nx, y, anor2, error )
+     call covariance( x, y, cov, error )
+     call stand_vari( x, anor1, error )
+     call stand_vari( y, anor2, error )
   else
-     call covariance( nx, x, y, cov )
-     call stand_vari( nx, x, anor1 )
-     call stand_vari( nx, y, anor2 )
+     call covariance( x, y, cov )
+     call stand_vari( x, anor1 )
+     call stand_vari( y, anor2 )
   end if
 
   cc=cov/(sqrt(anor1)*sqrt(anor2))
@@ -743,14 +765,16 @@ end subroutine Cor_Coe
 !---------------------------------
 !---------------------------------
 
-subroutine summ(nx,z,add,undeff)
+subroutine summ( z, add, undeff )
 ! undef ±黻Ԥ private 롼. ȤԲ.
   implicit none
-  integer, intent(in) :: nx
-  real, intent(in) :: z(nx)
+  real, intent(in) :: z(:)
   real, intent(inout) :: add
   real, intent(in), optional :: undeff
   integer :: i
+  integer :: nx
+
+  nx=size(z)
 
   add=0.0
   if(present(undeff))then
